pub struct OverlayManager(/* private fields */);Implementations
Sourceimpl OverlayManager
impl OverlayManager
pub fn new() -> Self
pub fn tint_0(&self) -> Color32
pub fn tint_1(&self) -> Color32
pub fn tint_2(&self) -> Color32
pub fn tint_3(&self) -> Color32
pub fn counter(&self) -> u8
pub fn order(&self) -> Order
pub fn paint_background(&self)
pub fn paint_middle(&self)
pub fn paint_foreground(&self)
pub fn paint_tooltip(&self)
pub fn paint_debug(&self)
Sourcepub fn window_opened(&self)
pub fn window_opened(&self)
Call this when you open a window
Sourcepub fn window_closed(&self)
pub fn window_closed(&self)
Call this when you close a window
pub fn recommended_order(&self) -> Order
pub fn calculate_alpha(&self) -> u8
Sourcepub fn overlay_tint(&self) -> Color32
pub fn overlay_tint(&self) -> Color32
Returns the tint color based on the counter
Sourcepub fn paint_overlay(&self, ctx: &Context, recommend_order: bool)
pub fn paint_overlay(&self, ctx: &Context, recommend_order: bool)
Paints a full-screen darkening overlay up to Foreground layer if needed
If recommend_order is true, it will choose an order based on the counter