Module utils

Module utils 

Constants

TINT_1
Should work for most images that are shown on a very dark background

Functions

apply_theme_changes
Apply any theme changes to the ui
bg_color_on_click
Give a background color to widgets like Button, ComboxBox, TextEdit, Slider, RadioButton
bg_color_on_hover
Give a background color to widgets like Button, ComboxBox, TextEdit, Slider, RadioButton
bg_color_on_idle
Give a background color to widgets like Button, ComboxBox, TextEdit, Slider, RadioButton
bg_color_on_open
Give a background color to widgets like Button, ComboxBox, TextEdit, Slider, RadioButton
border_on_click
Give a border to widgets like Button, ComboxBox, TextEdit, Slider, RadioButton
border_on_hover
Give a border to widgets like Button, ComboxBox, TextEdit, Slider, RadioButton
border_on_idle
Give a border to widgets like Button, ComboxBox, TextEdit, Slider, RadioButton
border_on_open
Give a border to widgets like ComboxBox
change_theme
Show a ComboBox to change the theme
frame_it
Put this ui on top of this frame
no_border
Removes the border from widgets like Button, ComboxBox, TextEdit, Slider, RadioButton
no_border_on_click
Removes the border from widgets like Button, ComboxBox, TextEdit, Slider, RadioButton
no_border_on_hover
Removes the border from widgets like Button, ComboxBox, TextEdit, Slider, RadioButton
no_border_on_idle
Removes the border from widgets like Button, ComboxBox, TextEdit, Slider, RadioButton
window_border
Window Border
window_fill
Window Fill Color