change_theme

Function change_theme 

pub fn change_theme(current_theme: &Theme, ui: &mut Ui) -> Option<Theme>
Show a ComboBox to change the theme

Returns the new theme if we select one, the new theme is also applied to the egui::Context