pub struct Theme {
pub dark_mode: bool,
pub overlay_manager: OverlayManager,
pub image_tint_recommended: bool,
pub kind: ThemeKind,
pub style: Style,
pub colors: ThemeColors,
pub text_sizes: TextSizes,
pub window_frame: Frame,
pub frame1: Frame,
pub frame2: Frame,
pub frame1_visuals: FrameVisuals,
pub frame2_visuals: FrameVisuals,
}Fields
dark_mode: boolTrue if the theme is dark
overlay_manager: OverlayManagerimage_tint_recommended: boolTrue if a tint is recomended to be applied to images to soften the contrast between the image and the background
This is usually true for themes with very dark background
kind: ThemeKindstyle: Stylecolors: ThemeColorstext_sizes: TextSizeswindow_frame: FrameUsed for window::window_frame
frame1: FrameBase container frame for major UI sections.
frame2: FrameFrame for nested elements, like individual list items.
frame1_visuals: FrameVisualsframe2_visuals: FrameVisualsImplementations
Sourceimpl Theme
impl Theme
Sourcepub fn new(kind: ThemeKind) -> Self
pub fn new(kind: ThemeKind) -> Self
Panics if the kind is ThemeKind::Custom
Use [Theme::from_custom()] instead
pub fn set_window_frame_colors(&mut self)
pub fn set_frame1_colors(&mut self)
pub fn set_frame2_colors(&mut self)
pub fn label_visuals(&self) -> LabelVisuals
pub fn combo_box_visuals(&self) -> ComboBoxVisuals
pub fn text_edit_visuals(&self) -> TextEditVisuals