pub struct ThemeColors {Show 17 fields
pub button_visuals: ButtonVisuals,
pub label_visuals: LabelVisuals,
pub combo_box_visuals: ComboBoxVisuals,
pub text_edit_visuals: TextEditVisuals,
pub title_bar: Color32,
pub bg: Color32,
pub widget_bg: Color32,
pub hover: Color32,
pub text: Color32,
pub text_muted: Color32,
pub highlight: Color32,
pub border: Color32,
pub accent: Color32,
pub error: Color32,
pub warning: Color32,
pub success: Color32,
pub info: Color32,
}Expand description
This is the color palette of the theme
Fields
label_visuals: LabelVisualscombo_box_visuals: ComboBoxVisualstext_edit_visuals: TextEditVisualstitle_bar: Color32The color for the title bar of the app (if using custom window frame)
bg: Color32Main BG color of the theme
widget_bg: Color32Widget BG color
This is the color of the widget backgrounds
hover: Color32The color to use when hovering over a widget
text: Color32Main text color
text_muted: Color32Muted text color
For example a hint inside a text field
highlight: Color32Highlight color
border: Color32Border color
accent: Color32Accent color
error: Color32Error color
Can be used to indicate something bad or to highlight a dangerous action
warning: Color32Warning color
success: Color32Success color
Can be used to indicate something good or to highlight a successful action
info: Color32Info color
Can be used for hyperlinks or to highlight something important