pub struct ThemeColors {Show 14 fields
pub bg: Color32,
pub bg2: Color32,
pub bg3: Color32,
pub bg4: Color32,
pub text: Color32,
pub text_muted: Color32,
pub highlight: Color32,
pub border: Color32,
pub primary: Color32,
pub secondary: Color32,
pub error: Color32,
pub warning: Color32,
pub success: Color32,
pub info: Color32,
}Expand description
This is the color palette of the theme
Fields
bg: Color32Main BG color of the theme
This is usually the darkest color of the theme
bg2: Color32BG2 color
A secondary bg color that is applied on top of the bg color
Usually this is the color of choice for a popup window or a base frame/container
Its a should be a lighter shade/color of the bg color.
bg3: Color32BG3 color
A third bg color that is applied on top of the bg2 color
Usually this is the color of choice for a frame/container that is already inside a Ui that uses the bg2 color
Its a should be a lighter shade/color of the bg2 color.
bg4: Color32BG 4 color
A fourth bg color that can be applied on top of the bg3 color
Usually this is the color of choice for a frame/container that is already inside a Ui that uses the bg3 color
Its a should be a lighter shade/color of the bg3 color.
text: Color32Main text color
text_muted: Color32Muted text color
For example a hint inside a text field
highlight: Color32Highlight color
border: Color32Border color
primary: Color32Primary action color
secondary: Color32Secondary action color
error: Color32Error color
Can be used to indicate something bad or to highlight a dangerous action
warning: Color32Warning color
success: Color32Success color
Can be used to indicate something good or to highlight a successful action
info: Color32Info color
Can be used for hyperlinks or to highlight something important